# pyautd3_emulator

![build](https://github.com/shinolab/pyautd3_emulator/workflows/build/badge.svg)
[![codecov](https://codecov.io/gh/shinolab/pyautd3_emulator/graph/badge.svg?precision=2)](https://codecov.io/gh/shinolab/pyautd3_emulator)
[![PyPI version](https://img.shields.io/pypi/v/pyautd3_emulator)](https://pypi.org/project/pyautd3_emulator/)

[autd3-emulator](https://github.com/shinolab/autd3-emulator) library for python3.11+

## Install

```
pip install pyautd3_emulator
```

## Example

see [example](./example)

## LICENSE

See [LICENSE](./LICENSE) and [ThirdPartyNotice](./ThirdPartyNotice.txt).

# Author

Shun Suzuki, 2025
